@@ -33,6 +33,6 @@ cp -f $LIBS usr/lib
 cp -f ${RRD_CMD} bin
 cp -f /usr/libexec/ld.so usr/libexec
 cp -f /bin/sh bin/sh
-cp /usr/local/share/rrdtool/fonts/*.ttf usr/local/share/rrdtool/fonts/
-echo rrdtool and libs installed in apache root
+cp -f /usr/local/share/rrdtool/fonts/DejaVuSansMono-Roman.ttf usr/local/share/rrdtool/fonts
+echo rrdtool, fonts and libs installed in apache root
 exit 1
