@@ -27,12 +27,16 @@ if (isset($symon['layout_dir'])) {
 	$file_layout = $symon['layout_dir'].'/'.$layout;
 	$extension = get_extension($layout);
 	$layout = basename($layout, '.layout');
-	if (is_file($file_layout) && $extension == 'layout') {
+	if (is_readable($file_layout) && $extension == 'layout') {
             $layout_files[] = $layout;
 	}
     }
     sort($layout_files);
-    $layouts = array_merge($layouts, $layout_files);
+    if (isset($symon['layout_first']) &&
+        ($symon['layout_first'] == 1))
+        $layouts = array_merge($layout_files, $layouts);
+    else
+        $layouts = array_merge($layouts, $layout_files);
 }
 
 if (count($layouts) > 0) {
@@ -171,6 +175,7 @@ $hidden = '';
 	$gts = $l->getgrouptitles();
 
 	$n = count($gts);
+	sort($gts);
 
 	if ($n > 1) {
 		echo '<div class="groups" width="100%">', "\n";
